RulesEngine class

Coordinates execution of all registered rules.

Takes the list of parsed files from Parser, runs every rule against every file, and returns the flat list of all findings.

Constructors

RulesEngine(List<AuditRule> rules)

Properties

hashCode int
The hash code for this object.
no setterinherited
rules List<AuditRule>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(List<ParsedFile> files) List<Issue>
Run every rule against every file. Returns all issues found.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited