Report class

The complete audit result.

Produced by the rules engine, consumed by reporters.

Constructors

Report({required String projectName, required int filesScanned, required int linesAnalyzed, required Duration elapsed, required List<Issue> issues, required AuditScore scores, required DateTime timestamp})

Properties

byCategory Map<String, List<Issue>>
Issues grouped by category in deterministic order.
no setter
elapsed Duration
final
filesScanned int
final
hashCode int
The hash code for this object.
no setterinherited
issues List<Issue>
final
linesAnalyzed int
final
projectName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scores AuditScore
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited