rules/deep_widget_nesting_rule library
Classes
- DeepWidgetNestingRule
-
Flags widget trees nested deeper than
_maxDepthinside a single build method. Deep trees are hard to read and refactor — extract subwidgets.
_maxDepth inside a single build
method. Deep trees are hard to read and refactor — extract subwidgets.