rules/print_in_production_rule library

Classes

PrintInProductionRule
Flags print(...) calls outside test files. Use a real logger so output can be turned off in release builds and shipped to crash analytics.