AuditScore class
Score breakdown by category, each 0–100.
Constructors
Properties
- api → int
-
final
- architecture → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- memory → int
-
final
- overall → int
-
Weighted average across all categories.
no setter
- performance → int
-
final
- quality → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- security → int
-
final
- ui → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited